@@ -345,15 +345,18 @@
 ##' @return vector of colors in hex code
 ##' @author Marius Hofert
 heatHCLgap <- function(beg, end, nBeg, nEnd, ngap, ...){
-    stopifnot(require(colorspace), length(beg)==3, length(end)==3)
+    stopifnot(requireNamespace("colorspace"), length(beg)==3, length(end)==3)
     stopifnot(nBeg >=0, nEnd >=0, nBeg+nEnd >= 1, ngap >=0)
-    n <- if(nBeg==0) nEnd else if(nEnd==0) nBeg else nBeg + nEnd + ngap # number of colors to generate on the path (ignore gap if nBeg==0 || nEnd==0
+    hexPol <- function(...) colorspace::hex(colorspace::polarLUV(...))
+    ## number of colors to generate on the path (ignore gap if nBeg==0 || nEnd==0):
+    n <- if(nBeg==0) nEnd else if(nEnd==0) nBeg else nBeg + nEnd + ngap
     heatHCL <- if(n==1){ # only one color: pick the right one of beg and end
-	if(nBeg==0) hex(polarLUV(H=end[1], C=end[2], L=end[3]))
-	else if(nEnd==0) hex(polarLUV(H=beg[1], C=beg[2], L=beg[3])) else stop("impossible case")
+	if     (nBeg==0) hexPol(H=end[1], C=end[2], L=end[3])
+	else if(nEnd==0) hexPol(H=beg[1], C=beg[2], L=beg[3])
+        else stop("impossible case")
     } else { # more than one color: interpolate in HCL space
-	heat_hcl(n, h=c(beg[1], end[1]), c.=c(beg[2], end[2]),
-		 l=c(beg[3], end[3]), ...) # all colors on the path
+	colorspace::heat_hcl(n, h = c(beg[1], end[1]), c. = c(beg[2], end[2]),
+                             l = c(beg[3], end[3]), ...) # all colors on the path
     }
     if(nBeg==0 || nEnd==0) heatHCL # colors without gap
     else c(heatHCL[seq_len(nBeg)], heatHCL[n-nEnd+seq_len(nEnd)]) # build in gap
@@ -478,16 +481,18 @@ pairsColList <- function(P, pdiv=c(1e-4, 1e-3, 1e-2, 0.05, 0.1, 0.5),
 	##	      dark colors.
 	if(is0bg.col.bottom && is0bg.col.top) { # use default color schemes
 	    bg.col <- match.arg(bg.col)
+	    hex2pLUV <- function(cc) {
+		stopifnot(require(colorspace)) # also for as(.,.) method
+		rev(as(colorspace::hex2RGB(cc), "polarLUV")@coords) # default
+	    }
 	    switch(bg.col,
 		   "ETHCL"={ # blue to yellow/white
-		       stopifnot(require(colorspace))
-		       bel <- rev(as(hex2RGB("#0066CC"), "polarLUV")@coords) # default
+		       bel <- hex2pLUV("#0066CC") # default
 		       bel[1] <- bel[1]-360 # map correctly to not run over green
 		       abo <- c(80, 30, 94) # yellow/white
 		   },
 		   "zurich"={ # sequential blue
-		       stopifnot(require(colorspace))
-		       bel <- rev(as(hex2RGB("#0066CC"), "polarLUV")@coords) # (Zurich coat of arms) blue
+		       bel <- hex2pLUV("#0066CC") # (Zurich coat of arms) blue
 		       bel[1] <- bel[1]-360 # map correctly to not run over green
 		       abo <- c(-100, 0, 94) # blue/white
 		   },
@@ -496,8 +501,7 @@ pairsColList <- function(P, pdiv=c(1e-4, 1e-3, 1e-2, 0.05, 0.1, 0.5),
 		       abo <- c(0, 0, 94) # gray/white
 		   },
 		   "baby"={
-		       stopifnot(require(colorspace))
-		       bel <- rev(as(hex2RGB("#0066CC"), "polarLUV")@coords)
+		       bel <- hex2pLUV("#0066CC")
 		       bel[1] <- bel[1]-360 # map correctly to not run over green
 		       abo <- c(0, 40, 100) # pink/white
 		   },
@@ -506,14 +510,15 @@ pairsColList <- function(P, pdiv=c(1e-4, 1e-3, 1e-2, 0.05, 0.1, 0.5),
 		       abo <- c(90, 30, 90) # yellow
 		   },
 		   "greenish"={ # self-constructed greenish color scheme
-		       stopifnot(require(colorspace))
-		       bel <- rev(as(hex2RGB("#283B4B"), "polarLUV")@coords) # "rgb2hcl"
-		       abo <- rev(as(hex2RGB("#EFEE69"), "polarLUV")@coords)
+		       bel <- hex2pLUV("#283B4B") # "rgb2hcl"
+		       abo <- hex2pLUV("#EFEE69")
 		   },
 		   stop("wrong color scheme"))
 	} else { # use the provided HCL color vectors
-	    if(is0bg.col.bottom && nColsBel > 0) stop("specify 'bg.col.bottom' or none of 'bg.col.bottom' and 'bg.col.top'")
-	    if(is0bg.col.top && nColsAbo > 0) stop("specify 'bg.col.top' or none of 'bg.col.bottom' and 'bg.col.top'")
+	    if(is0bg.col.bottom && nColsBel > 0)
+		stop("specify 'bg.col.bottom' or none of 'bg.col.bottom' and 'bg.col.top'")
+	    if(is0bg.col.top && nColsAbo > 0)
+		stop("specify 'bg.col.top' or none of 'bg.col.bottom' and 'bg.col.top'")
 	    bel <- bg.col.bottom # color *bel*ow signif.P
 	    abo <- bg.col.top # color *abo*ve signif.P
 	}
