@@ -58,7 +58,7 @@ tawnCopula <- function(param = NA_real_) {
 
 ptawnCopula <- function(u, copula) {
   dim <- copula@dimension
-  for (i in 1:dim) assign(paste("u", i, sep=""), u[,i])
+  for (i in 1:dim) assign(paste0("u", i), u[,i])
   has0 <- apply(u, 1, function(x) any(x <= 0)) # an ui = 0 would give NaN
   alpha <- copula@parameters[1]
   r <- c(eval(tawnCopula.cdf.algr[dim]))
@@ -68,7 +68,7 @@ ptawnCopula <- function(u, copula) {
 
 dtawnCopula <- function(u, copula, log=FALSE, ...) {
   dim <- copula@dimension
-  for (i in 1:dim) assign(paste("u", i, sep=""), u[,i])
+  for (i in 1:dim) assign(paste0("u", i), u[,i])
   alpha <- copula@parameters[1]
   val <- c(eval(tawnCopula.pdf.algr[dim]))
   ## FIXME: improve log-case
