@@ -29,11 +29,11 @@ void cramer_vonMises_grid(int *p, double *U, int *n, double *V, int *m,
 void multiplier(int *p, double *u0, int *m, double *u, int *n,
 		double *influ, int *N, double *s0);
 
-void cramer_vonMises_Pickands(int *n, int *m, double *S,
+void cramer_vonMises_Pickands(int n, int m, double *S,
 			      double *T, double *Atheta,
 			      double *stat);
 
-void cramer_vonMises_CFG(int *n, int *m, double *S,
+void cramer_vonMises_CFG(int n, int m, double *S,
 			 double *T, double *Atheta,
 			 double *stat);
 
